Changelog
=========

2.0.0 (2014-12-24)
------------------

- Add support for PyPy and PyPy3.

- Add support for Python 3.4.

- Add support for testing on Travis.

- Add support for Python 3.3.

- Replace deprecated ``zope.interface.implements`` usage with equivalent
  ``zope.interface.implementer`` decorator.

- Drop support for Python 2.4 and 2.5.


1.0.0 (2009-12-31)
------------------

- Extracted BasicAuthAdapter and FTPAuth adapters from zope.publisher. They
  should have never gone into that package in the first place.
